@@ -8,17 +8,13 @@ TASKS_TABLE = '__tasks__'
 
 
 async def migrate(connector: Connector) -> None:
-    try:
-        connection = await connector.get()
-        migrations = {key.replace('migration_', ''): value for key, value
-                      in globals().items() if key.startswith('migration')}
+    connection = await connector.get()
+    migrations = {key.replace('migration_', ''): value for key, value
+                  in globals().items() if key.startswith('migration')}
 
-        async with connection.transaction():
-            current = await get_version(connection)
-            for target, migration in migrations.items():
-                await apply_migration(current, target, migration, connection)
-    finally:
-        await connector.put(connection)
+    current = await get_version(connection)
+    for target, migration in migrations.items():
+        await apply_migration(current, target, migration, connection)
 
 
 async def apply_migration(current, target, migration, connection) -> None:
@@ -26,7 +22,7 @@ async def apply_migration(current, target, migration, connection) -> None:
         return None
     await migration(connection)
     table = f'{TASKS_SCHEMA}.{SETTINGS_TABLE}'
-    await connection.execute(f"""
+    await connection.fetch(f"""
     INSERT INTO {table} (key, value)
         VALUES ($1, $2)
         ON CONFLICT (key)
@@ -36,7 +32,7 @@ async def apply_migration(current, target, migration, connection) -> None:
 
 async def get_version(connection: Connection) -> str:
     table = f'{TASKS_SCHEMA}.{SETTINGS_TABLE}'
-    await connection.execute(
+    await connection.fetch(
         f'CREATE TABLE IF NOT EXISTS {table} (key TEXT UNIQUE, value TEXT)')
     result = await connection.fetch(
         f'SELECT key, value FROM {table} WHERE key = $1', VERSION_KEY)
@@ -46,15 +42,16 @@ async def get_version(connection: Connection) -> str:
 
 async def migration_001(connection: Connection):
     table = f'{TASKS_SCHEMA}.{TASKS_TABLE}'
-    await connection.execute(f"""
+    await connection.fetch(f"""
     CREATE TABLE IF NOT EXISTS {table} (
         id UUID PRIMARY KEY,
         created_at TIMESTAMPTZ,
         scheduled_at TIMESTAMPTZ,
         picked_at TIMESTAMPTZ,
-        expired_at TIMESTAMPTZ,
+        failed_at TIMESTAMPTZ,
+        timeout INTEGER,
+        lane TEXT,
         job TEXT,
-        status TEXT,
         attempts INTEGER,
-        data JSONB)
+        payload JSONB)
     """)
